]> git.mxchange.org Git - friendica.git/commitdiff
Removing of some warnings
authorMichael Vogel <icarus@dabo.de>
Thu, 24 Jul 2014 20:53:09 +0000 (22:53 +0200)
committerMichael Vogel <icarus@dabo.de>
Thu, 24 Jul 2014 20:53:09 +0000 (22:53 +0200)
include/text.php
index.php
library/dddbl2/inc/exceptions/QueryException.class.php

index 3c08fe3785815e0ecc21c60787166f7dc0a562df..26de709e3ea1d82d1f77c4cf6bd382ca95888c2b 100644 (file)
@@ -655,7 +655,7 @@ function attribute_contains($attr,$s) {
 if(! function_exists('logger')) {
 /* setup int->string log level map */
 $LOGGER_LEVELS = array();
-       
+
 /**
  * log levels:
  * LOGGER_NORMAL (default)
@@ -663,7 +663,7 @@ $LOGGER_LEVELS = array();
  * LOGGER_DEBUG
  * LOGGER_DATA
  * LOGGER_ALL
- * 
+ *
  * @global App $a
  * @global dba $db
  * @param string $msg
@@ -674,15 +674,16 @@ function logger($msg,$level = 0) {
        global $a;
        global $db;
        global $LOGGER_LEVELS;
-       
+
        if(($a->module == 'install') || (! ($db && $db->connected))) return;
 
-    if (count($LOGGER_LEVEL)==0){
-        foreach (get_defined_constants() as $k=>$v){
-            if (substr($k,0,7)=="LOGGER_") $LOGGER_LEVELS[$v] = substr($k,7,7);
-        }        
-    }
-    
+       if (count($LOGGER_LEVELS)==0){
+               foreach (get_defined_constants() as $k=>$v){
+                       if (substr($k,0,7)=="LOGGER_")
+                               $LOGGER_LEVELS[$v] = substr($k,7,7);
+               }
+       }
+
        $debugging = get_config('system','debugging');
        $loglevel  = intval(get_config('system','loglevel'));
        $logfile   = get_config('system','logfile');
index 335547d74b34e2de9deb2175afc3c25d03efde48..1b60071534c5df978ca5a9beea8e5e5adb5bd284 100644 (file)
--- a/index.php
+++ b/index.php
@@ -432,7 +432,7 @@ else
 $a->page['htmlhead'] = str_replace('{{$stylesheet}}',$stylesheet,$a->page['htmlhead']);
 //$a->page['htmlhead'] = replace_macros($a->page['htmlhead'], array('$stylesheet' => $stylesheet));
 
-if (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal")) {
+if (isset($_GET["mode"]) AND (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal"))) {
        $doc = new DOMDocument();
 
        $target = new DOMDocument();
@@ -455,7 +455,7 @@ if (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal")) {
        }
 }
 
-if ($_GET["mode"] == "raw") {
+if (isset($_GET["mode"]) AND ($_GET["mode"] == "raw")) {
 
        header("Content-type: text/html; charset=utf-8");
 
@@ -528,7 +528,7 @@ $profile = $a->profile;
 header("Content-type: text/html; charset=utf-8");
 
 
-if ($_GET["mode"] == "minimal") {
+if (isset($_GET["mode"]) AND ($_GET["mode"] == "minimal")) {
        //$page['content'] = substr($target->saveHTML(), 6, -8)."\n\n".
        //                      '<div id="conversation-end"></div>'."\n\n";
 
index 52c6250476c61151cc5181b0f6bee37e2b6bc70a..e282a18c9a722f4a5c91fe1445a77c21fc5d09e1 100644 (file)
@@ -19,7 +19,7 @@ class QueryException extends \Exception {
     * and print them as exception\r
     *\r
     **/\r
-    public function __construct(\PDOStatement $objPDO, $arrQueryDefinition) {\r
+    public function __construct(\PDOStatement $objPDO, array $arrQueryDefinition) {\r
         \r
         $strMessage = self::createErrorMessage($objPDO, $arrQueryDefinition);\r
         \r
@@ -38,7 +38,7 @@ class QueryException extends \Exception {
     * and query definition\r
     *\r
     **/\r
-    private function createErrorMessage($objPDO, $arrQueryDefinition) {\r
+    private function createErrorMessage(\PDOStatement $objPDO, array $arrQueryDefinition) {\r
       \r
       $strMessage  = self::flattenQueryErrorInfo($objPDO);\r
       $strMessage .= self::flattenQueryDefiniton($arrQueryDefinition);\r
@@ -57,7 +57,7 @@ class QueryException extends \Exception {
     * from the driver specific error message\r
     *\r
     **/\r
-    private function flattenQueryErrorInfo($objPDO) {\r
+    private function flattenQueryErrorInfo(\PDOStatement $objPDO) {\r
     \r
       $arrErrorInfo = $objPDO->errorInfo();\r
       \r
@@ -76,16 +76,18 @@ class QueryException extends \Exception {
     * \r
     * @return (string) a text version of the query definition\r
     * \r
* create an text, which contains all information \r
* of the query definition\r
     *\r
     **/\r
-    private function flattenQueryDefiniton($arrQueryDefinition) {\r
+    private function flattenQueryDefiniton(array $arrQueryDefinition) {\r
       \r
       $strMessage = "\nQuery-Definiton:\n";\r
       \r
       foreach($arrQueryDefinition AS $strKeyword => $strContent)\r
-        $strMessage .= "$strKeyword: $strContent\n";\r
+        if(is_scalar($strContent))\r
+          $strMessage .= "$strKeyword: $strContent\n";\r
       \r
       return $strMessage . "\n";\r
       \r
@@ -76,16 +76,18 @@ class QueryException extends \Exception {
     * @return (string) a text version of the query definition\r
     * \r
-    * create an text, which contains all information \r
-    * of the query definition\r
+    * create an text, which contains all *scalar* information \r
+    * of the query definition. if there are non-scalar information\r
+    * added, the will be excluded from output\r
     *\r
     **/\r